@@ -52,6 +52,13 @@ class RbxArrayBuilder {
   // Build array
   void Build();
 
+  // Returns a byte array of the image.
+  // The instance owns the returned object.
+  const char *GetImageBody() const;
+
+  // Returns the size of the image.
+  int GetImageSize() const;
+
   // Write image of array
   void WriteImage(OutputFileStream *ofs) const;
 
