@@ -55,6 +55,13 @@ class RxTrieBuilder {
   // Return -1 if key is not found or rx trie is not built yet.
   int GetIdFromKey(const string &key) const;
 
+  // Returns a byte array of the image.
+  // The instance owns the returned object.
+  const char *GetImageBody() const;
+
+  // Returns the size of the image.
+  int GetImageSize() const;
+
   // Write image of trie
   void WriteImage(OutputFileStream *ofs) const;
 
