@@ -705,7 +705,7 @@ Mozcの機能向上に役立てる（再ログイン後に変更は完了しま
     </message>
     <message>
         <source>New entry</source>
-        <translation type="obsolete">新しいエントリー</translation>
+        <translation type="obsolete">エントリーを追加</translation>
     </message>
     <message>
         <source>Remove entry</source>
@@ -729,7 +729,7 @@ Mozcの機能向上に役立てる（再ログイン後に変更は完了しま
     <name>KeyMapEditorDialog</name>
     <message>
         <source>New entry</source>
-        <translation type="obsolete">新しいエントリー</translation>
+        <translation type="obsolete">エントリーを追加</translation>
     </message>
     <message>
         <source>Remove selected entries</source>
@@ -843,7 +843,7 @@ Mozcの機能向上に役立てる（再ログイン後に変更は完了しま
     <name>RomanTableEditorDialog</name>
     <message>
         <source>New entry</source>
-        <translation type="obsolete">新しいエントリー</translation>
+        <translation type="obsolete">エントリーを追加</translation>
     </message>
     <message>
         <source>Remove selected entries</source>
@@ -1121,23 +1121,23 @@ Mozcの機能向上に役立てる（再ログイン後に変更は完了しま
     </message>
     <message>
         <location filename="config_dialog.cc" line="628"/>
-        <location filename="config_dialog.cc" line="1152"/>
+        <location filename="config_dialog.cc" line="1154"/>
         <source>Sync is not enabled</source>
         <translation>同期機能：オフ</translation>
     </message>
     <message>
-        <location filename="config_dialog.cc" line="782"/>
-        <location filename="config_dialog.cc" line="804"/>
+        <location filename="config_dialog.cc" line="784"/>
+        <location filename="config_dialog.cc" line="806"/>
         <source>Mozc Converter is not running. Settings were not saved.</source>
         <translation>変換サーバが反応していません。設定の反映に失敗しました。</translation>
     </message>
     <message>
-        <location filename="config_dialog.cc" line="906"/>
+        <location filename="config_dialog.cc" line="908"/>
         <source>Web Service extension enables Mozc to display third party usage dictionaries provided as an Web service API, e.g. REST (POX/JSON over HTTP). Note that candidate/preedit strings are sent to the Web service when this feature is enabled. Do you want to use Web Service extension?</source>
         <translation>Web 拡張を有効にすると、Web サービス (REST, POX/JSON over HTTP) が提供するコンテンツを Mozcの用例辞書として表示可能となります。候補ウインドウに表示中の文字列が外部サーバに送信されることにご注意下さい。続けますか?</translation>
     </message>
     <message>
-        <location filename="config_dialog.cc" line="929"/>
+        <location filename="config_dialog.cc" line="931"/>
         <source>When you reset Mozc settings, any changes you&apos;ve made will be reverted to the default settings. Do you want to reset settings? The following items are not reset with this operation.
  - Personalization data
  - Input history
@@ -1152,84 +1152,84 @@ Mozcの機能向上に役立てる（再ログイン後に変更は完了しま
  - 管理者用設定</translation>
     </message>
     <message>
-        <location filename="config_dialog.cc" line="986"/>
+        <location filename="config_dialog.cc" line="988"/>
         <source>Stop Sync</source>
         <translation>同期の解除</translation>
     </message>
     <message>
-        <location filename="config_dialog.cc" line="988"/>
+        <location filename="config_dialog.cc" line="990"/>
         <source>Start Sync</source>
         <translation>同期する</translation>
     </message>
     <message>
-        <location filename="config_dialog.cc" line="1004"/>
+        <location filename="config_dialog.cc" line="1006"/>
         <source>Stop sync and reset the auth token</source>
         <translation>同期の解除と認証コードのクリア</translation>
     </message>
     <message>
-        <location filename="config_dialog.cc" line="1005"/>
+        <location filename="config_dialog.cc" line="1007"/>
         <source>You are trying to stop sync and reset the auth token. To restart sync, you will need to get a new auth token.
 Do you really want to continue?</source>
         <translation>同期の解除と認証コードのクリアを行います。同期を再開するには、新しい認証コードを取得する必要があります。
 実行しますか？</translation>
     </message>
     <message>
-        <location filename="config_dialog.cc" line="1093"/>
+        <location filename="config_dialog.cc" line="1095"/>
         <source>Not synced yet</source>
         <translation>同期されていません</translation>
     </message>
     <message>
-        <location filename="config_dialog.cc" line="1097"/>
+        <location filename="config_dialog.cc" line="1099"/>
         <source>Last synced time: </source>
         <translation>最終同期時刻: </translation>
     </message>
     <message>
-        <location filename="config_dialog.cc" line="1140"/>
+        <location filename="config_dialog.cc" line="1142"/>
         <source>Waiting for server to be ready</source>
         <translation>サーバの状態を確認しています.. この処理は最大2分かかります</translation>
     </message>
     <message>
-        <location filename="config_dialog.cc" line="1169"/>
+        <location filename="config_dialog.cc" line="1171"/>
         <source>Authorization failed.</source>
         <translation>認証に失敗しました。</translation>
     </message>
     <message>
-        <location filename="config_dialog.cc" line="1172"/>
+        <location filename="config_dialog.cc" line="1174"/>
         <source>Cannot save dictionaries because Sync Dictionary exceeds its entry size limit.</source>
         <translation>単語数の上限を超えたため同期用辞書をセーブできません。</translation>
     </message>
     <message>
-        <location filename="config_dialog.cc" line="1176"/>
+        <location filename="config_dialog.cc" line="1178"/>
         <source>Cannot save dictionaries because Sync Dictionary exceeds its binary size limit.</source>
         <translation>ファイルサイズの上限を超えたため同期用辞書をセーブできません。</translation>
     </message>
     <message>
-        <location filename="config_dialog.cc" line="1180"/>
+        <location filename="config_dialog.cc" line="1182"/>
         <source>Cannot save dictionaries because the number of dictionaries for sync exceeds its limit.</source>
         <translation>同期用辞書の数が上限を超えたため辞書をセーブできません。</translation>
     </message>
     <message>
-        <location filename="config_dialog.cc" line="1184"/>
+        <location filename="config_dialog.cc" line="1186"/>
         <source>Unknown error was found.</source>
         <translation>未知のエラーです。</translation>
     </message>
     <message>
-        <location filename="config_dialog.cc" line="1196"/>
+        <location filename="config_dialog.cc" line="1198"/>
         <source>Authorization error</source>
         <translation>認証失敗</translation>
     </message>
     <message>
-        <location filename="config_dialog.cc" line="1201"/>
+        <location filename="config_dialog.cc" line="1203"/>
         <source>Dictionary sync error</source>
         <translation>辞書同期エラー</translation>
     </message>
     <message>
-        <location filename="config_dialog.cc" line="1204"/>
+        <location filename="config_dialog.cc" line="1206"/>
         <source>Unknown sync error</source>
         <translation>未知の同期エラー</translation>
     </message>
     <message>
-        <location filename="config_dialog.cc" line="1219"/>
+        <location filename="config_dialog.cc" line="1221"/>
         <source>You are trying to clear all the data in the sync server.
 Do you really want to continue?</source>
         <translation>Google サーバー上の同期データを全て消去します。
@@ -1244,12 +1244,12 @@ Do you really want to continue?</source>
         <translation type="obsolete">同期失敗</translation>
     </message>
     <message>
-        <location filename="config_dialog.cc" line="1146"/>
+        <location filename="config_dialog.cc" line="1148"/>
         <source>During synchronization</source>
         <translation>同期中です</translation>
     </message>
     <message>
-        <location filename="config_dialog.cc" line="1218"/>
+        <location filename="config_dialog.cc" line="1220"/>
         <source>Clear all sync data in Google servers</source>
         <translation>Google サーバー上の同期データを全て消去する</translation>
     </message>
@@ -1258,14 +1258,14 @@ Do you really want to continue?</source>
         <location filename="config_dialog.cc" line="420"/>
         <location filename="config_dialog.cc" line="434"/>
         <location filename="config_dialog.cc" line="442"/>
-        <location filename="config_dialog.cc" line="767"/>
-        <location filename="config_dialog.cc" line="781"/>
-        <location filename="config_dialog.cc" line="791"/>
-        <location filename="config_dialog.cc" line="803"/>
-        <location filename="config_dialog.cc" line="813"/>
-        <location filename="config_dialog.cc" line="825"/>
-        <location filename="config_dialog.cc" line="905"/>
-        <location filename="config_dialog.cc" line="928"/>
+        <location filename="config_dialog.cc" line="769"/>
+        <location filename="config_dialog.cc" line="783"/>
+        <location filename="config_dialog.cc" line="793"/>
+        <location filename="config_dialog.cc" line="805"/>
+        <location filename="config_dialog.cc" line="815"/>
+        <location filename="config_dialog.cc" line="827"/>
+        <location filename="config_dialog.cc" line="907"/>
+        <location filename="config_dialog.cc" line="930"/>
         <source>Mozc settings</source>
         <translation>Mozc プロパティ</translation>
     </message>
@@ -1290,22 +1290,22 @@ Do you really want to continue?</source>
         <translation>設定の反映に失敗しました</translation>
     </message>
     <message>
-        <location filename="config_dialog.cc" line="768"/>
+        <location filename="config_dialog.cc" line="770"/>
         <source>Do you want to clear personalization data? Input history is not reset with this operation. Please open &quot;suggestion&quot; tab to remove input history data.</source>
         <translation>学習結果がリセットされます。実行しますか？ 入力履歴データはリセットされません。入力履歴データのリセットは「サジェスト→全入力履歴の削除」で行えます。</translation>
     </message>
     <message>
-        <location filename="config_dialog.cc" line="826"/>
+        <location filename="config_dialog.cc" line="828"/>
         <source>Mozc Converter is not running. Operation was not executed.</source>
         <translation>Mozcコンバーターが起動していません。設定の反映に失敗しました。</translation>
     </message>
     <message>
-        <location filename="config_dialog.cc" line="792"/>
+        <location filename="config_dialog.cc" line="794"/>
         <source>Do you want to clear all history data?</source>
         <translation>すべての入力履歴が削除されます。実行しますか？</translation>
     </message>
     <message>
-        <location filename="config_dialog.cc" line="814"/>
+        <location filename="config_dialog.cc" line="816"/>
         <source>Do you want to clear unused history data?</source>
         <translation>サジェスト経由で入力されなかった履歴が削除されます。実行しますか？</translation>
     </message>
@@ -1318,64 +1318,69 @@ Do you really want to continue?</source>
         <translation>編集</translation>
     </message>
     <message>
-        <location filename="generic_table_editor.cc" line="132"/>
-        <location filename="generic_table_editor.cc" line="177"/>
-        <location filename="generic_table_editor.cc" line="188"/>
-        <location filename="generic_table_editor.cc" line="210"/>
-        <location filename="generic_table_editor.cc" line="218"/>
-        <location filename="generic_table_editor.cc" line="226"/>
-        <location filename="generic_table_editor.cc" line="248"/>
+        <location filename="generic_table_editor.cc" line="136"/>
+        <location filename="generic_table_editor.cc" line="181"/>
+        <location filename="generic_table_editor.cc" line="192"/>
+        <location filename="generic_table_editor.cc" line="214"/>
+        <location filename="generic_table_editor.cc" line="222"/>
+        <location filename="generic_table_editor.cc" line="230"/>
+        <location filename="generic_table_editor.cc" line="252"/>
         <source>Mozc settings</source>
         <translation>Mozc プロパティ</translation>
     </message>
     <message>
-        <location filename="generic_table_editor.cc" line="133"/>
-        <location filename="generic_table_editor.cc" line="178"/>
+        <location filename="generic_table_editor.cc" line="137"/>
+        <location filename="generic_table_editor.cc" line="182"/>
         <source>No entry is selected</source>
         <translation>エントリーが選択されていません</translation>
     </message>
     <message>
-        <location filename="generic_table_editor.cc" line="189"/>
+        <location filename="generic_table_editor.cc" line="193"/>
         <source>You can&apos;t have more than %1 entries</source>
         <translation>%1 個以上のエントリーは登録できません</translation>
     </message>
     <message>
-        <location filename="generic_table_editor.cc" line="201"/>
+        <location filename="generic_table_editor.cc" line="205"/>
         <source>import from file</source>
         <translation>インポート</translation>
     </message>
     <message>
-        <location filename="generic_table_editor.cc" line="211"/>
+        <location filename="generic_table_editor.cc" line="215"/>
         <source>File not found</source>
         <translation>ファイルが見つかりません</translation>
     </message>
     <message>
-        <location filename="generic_table_editor.cc" line="219"/>
+        <location filename="generic_table_editor.cc" line="223"/>
         <source>The specified file is too large (&gt;=100K byte)</source>
         <translation>ファイルサイズが大きすぎて読み込めません</translation>
     </message>
     <message>
-        <location filename="generic_table_editor.cc" line="227"/>
+        <location filename="generic_table_editor.cc" line="231"/>
         <source>Import failed</source>
         <translation>インポートに失敗しました</translation>
     </message>
     <message>
-        <location filename="generic_table_editor.cc" line="238"/>
+        <location filename="generic_table_editor.cc" line="242"/>
         <source>export to file</source>
         <translation>エクスポート</translation>
     </message>
     <message>
-        <location filename="generic_table_editor.cc" line="249"/>
+        <location filename="generic_table_editor.cc" line="253"/>
         <source>Export failed</source>
         <translation>エクスポートに失敗しました</translation>
     </message>
     <message>
-        <location filename="generic_table_editor.cc" line="282"/>
-        <source>New entry</source>
-        <translation>新しいエントリー</translation>
+        <location filename="generic_table_editor.cc" line="291"/>
+        <source>Edit entry</source>
+        <translation>エントリーを編集</translation>
     </message>
     <message>
-        <location filename="generic_table_editor.cc" line="283"/>
+        <location filename="generic_table_editor.cc" line="293"/>
+        <source>New entry</source>
+        <translation>エントリーを追加</translation>
+    </message>
+    <message>
+        <location filename="generic_table_editor.cc" line="294"/>
         <source>Remove entry</source>
         <translation>エントリーを削除</translation>
     </message>
@@ -1385,7 +1390,7 @@ Do you really want to continue?</source>
     <message>
         <location filename="keymap_editor.cc" line="220"/>
         <source>New entry</source>
-        <translation>新しいエントリー</translation>
+        <translation>エントリーを追加</translation>
     </message>
     <message>
         <location filename="keymap_editor.cc" line="222"/>
@@ -1423,52 +1428,52 @@ Do you really want to continue?</source>
         <translation>エクスポート...</translation>
     </message>
     <message>
-        <location filename="keymap_editor.cc" line="280"/>
+        <location filename="keymap_editor.cc" line="279"/>
         <source>Mozc keymap editor</source>
         <translation>Mozc キー設定</translation>
     </message>
     <message>
-        <location filename="keymap_editor.cc" line="284"/>
+        <location filename="keymap_editor.cc" line="283"/>
         <source>Mode</source>
         <translation>モード</translation>
     </message>
     <message>
-        <location filename="keymap_editor.cc" line="284"/>
+        <location filename="keymap_editor.cc" line="283"/>
         <source>Key</source>
         <translation>入力キー</translation>
     </message>
     <message>
-        <location filename="keymap_editor.cc" line="284"/>
+        <location filename="keymap_editor.cc" line="283"/>
         <source>Command</source>
         <translation>コマンド</translation>
     </message>
     <message>
-        <location filename="keymap_editor.cc" line="368"/>
-        <location filename="keymap_editor.cc" line="408"/>
-        <location filename="keymap_editor.cc" line="427"/>
-        <location filename="keymap_editor.cc" line="463"/>
+        <location filename="keymap_editor.cc" line="367"/>
+        <location filename="keymap_editor.cc" line="407"/>
+        <location filename="keymap_editor.cc" line="426"/>
+        <location filename="keymap_editor.cc" line="462"/>
         <source>Mozc settings</source>
         <translation>Mozcプロパティ</translation>
     </message>
     <message>
-        <location filename="keymap_editor.cc" line="369"/>
+        <location filename="keymap_editor.cc" line="368"/>
         <source>Current keymap table is empty. You might want to import a pre-defined keymap table first</source>
         <translation>有効なキーマップがありません。定義済みのキーマップをインポートするか、有効なキーマップを追加してください。</translation>
     </message>
     <message>
-        <location filename="keymap_editor.cc" line="409"/>
+        <location filename="keymap_editor.cc" line="408"/>
         <source>Invalid key:
 %1</source>
         <translation>無効な入力キーです:
 %1</translation>
     </message>
     <message>
-        <location filename="keymap_editor.cc" line="428"/>
+        <location filename="keymap_editor.cc" line="427"/>
         <source>The keymaps for IME ON and Reconversion will be applied after new applications.</source>
         <translation>IME の有効化と再変換に対するキー設定は、新しいアプリケーションから有効になります。</translation>
     </message>
     <message>
-        <location filename="keymap_editor.cc" line="464"/>
+        <location filename="keymap_editor.cc" line="463"/>
         <source>Do you want to overwrite the current keymaps?</source>
         <translation>現在のキー設定が上書きされます。実行しますか？</translation>
     </message>
