@@ -1,4 +1,4 @@
-// Copyright 2010-2011, Google Inc.
+// Copyright 2010-2012, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -56,6 +56,9 @@ class RomanTableEditorDialog : public GenericTableEditorDialog {
   virtual void OnEditMenuAction(QAction *action);
 
  protected:
+  virtual string GetDefaultFilename() const {
+    return "romantable.txt";
+  }
   virtual bool LoadFromStream(istream *is);
   virtual bool Update();
 
