@@ -34,7 +34,7 @@
 #include "ipc/ipc.h"
 #include "renderer/renderer_interface.h"
 #include "renderer/renderer_client.h"
-#include "session/commands.pb.h"
+#include "renderer/renderer_command.pb.h"
 #include "testing/base/public/gunit.h"
 
 namespace mozc {
@@ -169,6 +169,9 @@ class TestRendererLauncher : public RendererLauncherInterface {
     set_pending_command_called_ = true;
   }
 
+  virtual void set_suppress_error_dialog(bool suppress) {
+  }
+
   void Reset() {
     start_renderer_called_ = false;
     force_terminate_renderer_called_ = false;
