@@ -122,11 +122,21 @@ class InfolistWindowTest : public testing::Test {
     EXPECT_CALL(*testkit->gtk_mock, GSignalConnect(
         kDummyWindow, StrEq("destroy"),
         G_CALLBACK(GtkWindowBase::OnDestroyThunk), _));
+    EXPECT_CALL(*testkit->gtk_mock, GSignalConnect(
+        kDummyWindow, StrEq("button-press-event"),
+        G_CALLBACK(GtkWindowBase::OnMouseDownThunk), _));
+    EXPECT_CALL(*testkit->gtk_mock, GSignalConnect(
+        kDummyWindow, StrEq("button-release-event"),
+        G_CALLBACK(GtkWindowBase::OnMouseUpThunk), _));
     EXPECT_CALL(*testkit->gtk_mock, GSignalConnect(
         kDummyCanvas, StrEq("expose-event"),
         G_CALLBACK(GtkWindowBase::OnPaintThunk), _));
     EXPECT_CALL(*testkit->gtk_mock,
                 GtkContainerAdd(kDummyWindow, kDummyCanvas));
+    EXPECT_CALL(*testkit->gtk_mock,
+                GtkWidgetAddEvents(kDummyWindow, GDK_BUTTON_PRESS_MASK));
+    EXPECT_CALL(*testkit->gtk_mock,
+                GtkWidgetAddEvents(kDummyWindow, GDK_BUTTON_RELEASE_MASK));
   }
 
   InfolistWindowTestKit SetUpInfolistWindow() {
@@ -459,6 +469,15 @@ TEST_F(InfolistWindowTest, GetRenderingRectsTest) {
   }
 }
 
+TEST_F(InfolistWindowTest, ReloadFontConfigTest) {
+  InfolistWindowTestKit testkit = SetUpInfolistWindow();
+  const char kDummyFontDescription[] = "Foo,Bar,Baz";
+  EXPECT_CALL(*testkit.text_renderer_mock,
+              ReloadFontConfig(StrEq(kDummyFontDescription)));
+  testkit.window->ReloadFontConfig(kDummyFontDescription);
+  FinalizeTestKit(&testkit);
+}
+
 }  // namespace gtk
 }  // namespace renderer
 }  // namespace mozc
