@@ -54,8 +54,8 @@
 #include "base/base.h"
 #include "base/scoped_ptr.h"
 #include "base/util.h"
-#include "session/commands.pb.h"
-#include "win32/base/font_util.h"
+#include "renderer/renderer_command.pb.h"
+#include "renderer/win32/win32_font_util.h"
 
 namespace mozc {
 namespace renderer {
