@@ -41,23 +41,22 @@
 
 namespace mozc {
 
-CalculatorRewriter::CalculatorRewriter() {
+CalculatorRewriter::CalculatorRewriter(
+    const ConverterInterface *parent_converter)
+    : parent_converter_(parent_converter) {
+  DCHECK(parent_converter_);
 }
 
 CalculatorRewriter::~CalculatorRewriter() {}
 
-bool CalculatorRewriter::Rewrite(Segments *segments) const {
-  return RewriteForRequest(ConversionRequest(), segments);
-}
-
 // Rewrites candidates when conversion segments of |segments| represents an
 // expression that can be calculated. In such case, if |segments| consists
 // of multiple segments, it merges them by calling ConverterInterface::
 // ResizeSegment(), otherwise do calculation and insertion.
 // TODO(tok): It currently calculates same expression twice, if |segments| is
 //            a valid expression.
-bool CalculatorRewriter::RewriteForRequest(const ConversionRequest &request,
-                                           Segments *segments) const {
+bool CalculatorRewriter::Rewrite(const ConversionRequest &request,
+                                 Segments *segments) const {
   if (!GET_CONFIG(use_calculator)) {
     return false;
   }
@@ -97,13 +96,12 @@ bool CalculatorRewriter::RewriteForRequest(const ConversionRequest &request,
   }
 
   // Merge all conversion segments.
-  ConverterInterface *converter = ConverterFactory::GetConverter();
   int offset = Util::CharsLen(merged_key) -
                    Util::CharsLen(segments->conversion_segment(0).key());
   // ConverterInterface::ResizeSegment() calls Rewriter::Rewrite(), so
   // CalculatorRewriter::Rewrite() is recursively called with merged
   // conversion segment.
-  if (!converter->ResizeSegment(segments, request, 0, offset)) {
+  if (!parent_converter_->ResizeSegment(segments, request, 0, offset)) {
     LOG(ERROR) << "Failed to merge conversion segments";
     return false;
   }
