@@ -48,6 +48,7 @@
 #include "converter/conversion_request.h"
 #include "converter/segments.h"
 #include "session/commands.pb.h"
+#include "session/request_handler.h"
 
 namespace mozc {
 
@@ -1248,6 +1249,9 @@ DateRewriter::DateRewriter() {}
 DateRewriter::~DateRewriter() {}
 
 int DateRewriter::capability() const {
+  if (GET_REQUEST(mixed_conversion)) {
+    return RewriterInterface::ALL;
+  }
   return RewriterInterface::CONVERSION;
 }
 
