@@ -35,6 +35,7 @@
 #include "base/base.h"
 #include "base/singleton.h"
 #include "base/util.h"
+#include "converter/conversion_request.h"
 #include "converter/segments.h"
 #include "rewriter/rewriter_interface.h"
 
@@ -181,7 +182,8 @@ FortuneRewriter::FortuneRewriter() {}
 
 FortuneRewriter::~FortuneRewriter() {}
 
-bool FortuneRewriter::Rewrite(Segments *segments) const {
+bool FortuneRewriter::Rewrite(const ConversionRequest &request,
+                              Segments *segments) const {
   if (segments->conversion_segments_size() != 1) {
     return false;
   }
