@@ -42,6 +42,7 @@
 #include "rewriter/rewriter_interface.h"
 #include "rewriter/embedded_dictionary.h"
 #include "session/commands.pb.h"
+#include "session/request_handler.h"
 
 namespace mozc {
 
@@ -158,6 +159,9 @@ SingleKanjiRewriter::SingleKanjiRewriter() {}
 SingleKanjiRewriter::~SingleKanjiRewriter() {}
 
 int SingleKanjiRewriter::capability() const {
+  if (GET_REQUEST(mixed_conversion)) {
+    return RewriterInterface::ALL;
+  }
   return RewriterInterface::CONVERSION;
 }
 
