@@ -34,6 +34,7 @@
 #include "converter/segments.h"
 #include "rewriter/single_kanji_rewriter.h"
 #include "session/commands.pb.h"
+#include "session/request_test_util.h"
 #include "testing/base/public/gunit.h"
 
 DECLARE_string(test_tmpdir);
@@ -53,6 +54,9 @@ class SingleKanjiRewriterTest : public testing::Test {
 TEST_F(SingleKanjiRewriterTest, CapabilityTest) {
   SingleKanjiRewriter rewriter;
 
+  commands::Request request;
+  request.set_mixed_conversion(false);
+  commands::ScopedRequestForUnittest scoped_request(request);
   EXPECT_EQ(RewriterInterface::CONVERSION, rewriter.capability());
 }
 
@@ -79,4 +83,20 @@ TEST_F(SingleKanjiRewriterTest, SetKeyTest) {
   }
 }
 
+TEST_F(SingleKanjiRewriterTest, MobileEnvironmentTest) {
+  commands::Request request;
+  SingleKanjiRewriter rewriter;
+
+  {
+    request.set_mixed_conversion(true);
+    commands::ScopedRequestForUnittest scoped_request(request);
+    EXPECT_EQ(RewriterInterface::ALL, rewriter.capability());
+  }
+
+  {
+    request.set_mixed_conversion(false);
+    commands::ScopedRequestForUnittest scoped_request(request);
+    EXPECT_EQ(RewriterInterface::CONVERSION, rewriter.capability());
+  }
+}
 }  // namespace mozc
