@@ -38,18 +38,19 @@
 namespace mozc {
 
 class ConversionRequest;
-class Segments;
-class Segment;
+class ConverterInterface;
 class LRUStorage;
+class Segment;
+class Segments;
 
-class UserBoundaryHistoryRewriter: public RewriterInterface {
+class UserBoundaryHistoryRewriter : public RewriterInterface {
  public:
-  UserBoundaryHistoryRewriter();
+  explicit UserBoundaryHistoryRewriter(
+      const ConverterInterface *parent_converter);
   virtual ~UserBoundaryHistoryRewriter();
 
-  virtual bool Rewrite(Segments *segments) const;
-  virtual bool RewriteForRequest(const ConversionRequest &request,
-                                 Segments *segments) const;
+  virtual bool Rewrite(const ConversionRequest &request,
+                       Segments *segments) const;
 
   virtual void Finish(Segments *segments);
 
@@ -70,8 +71,10 @@ class UserBoundaryHistoryRewriter: public RewriterInterface {
   void Insert(const vector<const Segment *> &segs1,
               const vector<const Segment *> &segs2);
 
+  const ConverterInterface *parent_converter_;
   scoped_ptr<LRUStorage> storage_;
 };
-}
+
+}  // namespace mozc
 
 #endif  // MOZC_REWRITER_USER_BOUNDARY_HISTORY_REWRITER_H_
