@@ -32,14 +32,10 @@
 #include "server/mozc_server.h"
 #include "session/session_factory_manager.h"
 #include "session/japanese_session_factory.h"
-#include "languages/global_language_spec.h"
-#include "languages/japanese/lang_dep_spec.h"
 
 int main(int argc, char* argv[]) {
   mozc::server::InitGoogleAndMozcServer(argv[0], &argc, &argv, false);
 
-  mozc::japanese::LangDepSpecJapanese spec;
-  mozc::language::GlobalLanguageSpec::SetLanguageDependentSpec(&spec);
   mozc::session::JapaneseSessionFactory session_factory;
   mozc::session::SessionFactoryManager::SetSessionFactory(&session_factory);
 
