@@ -42,6 +42,7 @@
 #include "composer/composer.h"
 #include "session/internal/candidate_list.h"
 #include "session/internal/session_output.h"
+#include "session/request_handler.h"
 #include "transliteration/transliteration.h"
 
 namespace mozc {
@@ -373,7 +374,7 @@ void PrependCandidates(const Segment &previous_segment,
   const size_t cands_size = previous_segment.candidates_size();
   for (size_t i = 0; i < cands_size; ++i) {
     Segment::Candidate *candidate = segment->push_front_candidate();
-    *candidate = previous_segment.candidate(cands_size - i - 1);  // copy
+    candidate->CopyFrom(previous_segment.candidate(cands_size - i - 1));
   }
   *(segment->mutable_meta_candidates()) = previous_segment.meta_candidates();
 }
@@ -388,7 +389,6 @@ bool SessionConverter::SuggestWithPreferences(
     const composer::Composer &composer,
     const ConversionPreferences &preferences) {
   DCHECK(CheckState(COMPOSITION | SUGGESTION));
-  bool use_partial_suggestion = false;
   candidate_list_visible_ = false;
 
   // Normalize the current state by resetting the previous state.
@@ -402,14 +402,16 @@ bool SessionConverter::SuggestWithPreferences(
   // Initialize the segments for suggestion.
   SetConversionPreferences(preferences, segments_.get());
 
+  const bool use_partial_suggestion = GET_REQUEST(mixed_conversion);
   const size_t cursor = composer.GetCursor();
   if (cursor == composer.GetLength() || cursor == 0 ||
       !use_partial_suggestion) {
-    if (!converter_->StartSuggestionWithComposer(segments_.get(), &composer)) {
+    if (!converter_->StartSuggestionForRequest(
+            ConversionRequest(&composer), segments_.get())) {
       // TODO(komatsu): Because suggestion is a prefix search, once
       // StartSuggestion returns false, this GetSuggestion always
       // returns false.  Refactor it.
-      VLOG(1) << "StartSuggestion() returns no suggestions.";
+      VLOG(1) << "StartSuggestionForRequest() returns no suggestions.";
 
       // Clear segments and keep the context
       converter_->CancelConversion(segments_.get());
@@ -476,8 +478,9 @@ bool SessionConverter::PredictWithPreferences(
   segments_->clear_conversion_segments();
 
   if (predict_expand || predict_first) {
-    if (!converter_->StartPredictionWithComposer(segments_.get(), &composer)) {
-      LOG(WARNING) << "StartPredictionWithComposer() failed";
+    if (!converter_->StartPredictionForRequest(
+            ConversionRequest(&composer), segments_.get())) {
+      LOG(WARNING) << "StartPredictionForRequest() failed";
 
       // TODO(komatsu): Perform refactoring after checking the stability test.
       //
@@ -537,15 +540,16 @@ bool SessionConverter::ExpandSuggestionWithPreferences(
   // Without this statement we can add additional candidates into
   // existing segments.
 
-  bool use_partial_suggestion = false;
+  const bool use_partial_suggestion = GET_REQUEST(mixed_conversion);
   const size_t cursor = composer.GetCursor();
   if (cursor == composer.GetLength() || cursor == 0 ||
       !use_partial_suggestion) {
     // This is abuse of StartPrediction().
     // TODO(matsuzakit or yamaguchi): Add ExpandSuggestion method
     //    to Converter class.
-    if (!converter_->StartPredictionWithComposer(segments_.get(), &composer)) {
-      LOG(WARNING) << "StartPrediction() failed";
+    if (!converter_->StartPredictionForRequest(
+            ConversionRequest(&composer), segments_.get())) {
+      LOG(WARNING) << "StartPredictionForRequest() failed";
     }
   } else {
     string query;
@@ -659,7 +663,10 @@ bool SessionConverter::CommitSuggestionInternal(
 
   const size_t result_length = Util::CharsLen(result_.key());
   const size_t preedit_length = Util::CharsLen(preedit);
-  bool use_partial_suggestion = false;
+  const bool use_partial_suggestion = GET_REQUEST(zero_query_suggestion);
+
+  // TODO(horo): When we will support hardware keyboard and introduce
+  // shift+enter keymap in Android, this if condition may be insufficient.
   if (use_partial_suggestion && (result_length < preedit_length)) {
     // A candidate was chosen from partial suggestion.
     converter_->CommitPartialSuggestionSegmentValue(
