@@ -37,6 +37,7 @@
 #include "dictionary/user_dictionary_storage.h"
 #include "dictionary/user_dictionary_util.h"
 #include "storage/registry.h"
+#include "sync/logging.h"
 #include "sync/user_dictionary_sync_util.h"
 #include "sync/sync.pb.h"
 #include "sync/sync_util.h"
@@ -60,10 +61,11 @@ bool UserDictionaryAdapter::SetDownloadedItems(
   vector<const UserDictionarySyncUtil::UserDictionaryStorageBase *>
       remote_updates;
 
-  VLOG(1) << "Start SetDownloadedItems: " << items.size() << " items";
+  SYNC_VLOG(1) << "Start SetDownloadedItems: "
+               << items.size() << " items";
 
   if (items.size() == 0) {
-    LOG(WARNING) << "No items found";
+    SYNC_VLOG(1) << "No items found";
     return true;
   }
 
@@ -82,12 +84,12 @@ bool UserDictionaryAdapter::SetDownloadedItems(
         item.value().GetExtension(sync::UserDictionaryValue::ext);
 
     if (!value.has_user_dictionary_storage()) {
-      LOG(ERROR) << "value has no user_dictionary_storage";
+      SYNC_VLOG(1) << "value has no user_dictionary_storage";
       continue;
     }
 
     if (!key.has_bucket_id()) {
-      LOG(ERROR) << "value has no bucket_id";
+      SYNC_VLOG(1) << "value has no bucket_id";
       continue;
     }
 
@@ -96,83 +98,107 @@ bool UserDictionaryAdapter::SetDownloadedItems(
   }
 
   if (bucket_id != kuint32max && !SetBucketId(bucket_id)) {
-    LOG(ERROR) << "cannot save bucket id";
+    SYNC_VLOG(1) << "cannot save bucket id";
     return false;
   }
 
+  SYNC_VLOG(1) << "current backet_id=" << bucket_id;
+
   const string prev_file = GetLastSyncedUserDictionaryFileName();
   const string cur_file = GetUserDictionaryFileName();
 
+  SYNC_VLOG(1) << "comparing " << prev_file << " with " << cur_file;
   if (Util::IsEqualFile(prev_file, cur_file)) {
     if (remote_updates.empty()) {
-      VLOG(1) << "No local_update and no remote_updates.";
+      SYNC_VLOG(1) << "no local_update and no remote_updates.";
       return true;
     }
 
-    VLOG(1) << "No local_update and has remote_updates.";
+    SYNC_VLOG(1) << "no local_update and has remote_updates.";
     UserDictionaryStorage cur_storage(cur_file);
     cur_storage.Load();
+    SYNC_VLOG(1) << "merging remote_updates to current storage.";
     UserDictionarySyncUtil::MergeUpdates(remote_updates, &cur_storage);
-    if (!UserDictionarySyncUtil::LockAndSaveStorage(&cur_storage)) {
+    if (!UserDictionarySyncUtil::VerifyLockAndSaveStorage(&cur_storage)) {
+      SYNC_VLOG(1) << "cannot save cur_storage.";
       return false;
     }
+    SYNC_VLOG(1) << "copying " << cur_file << " to " << prev_file;
     if (!SyncUtil::CopyLastSyncedFile(cur_file, prev_file)) {
-      LOG(ERROR) << "cannot copy " << cur_file << " to " << prev_file;
+      SYNC_VLOG(1) << "cannot copy " << cur_file << " to " << prev_file;
       return false;
     }
   } else {   // Updates found on the local.
     if (remote_updates.empty()) {
-      VLOG(1) << "Has local_update and no remote_updates.";
+      SYNC_VLOG(1) << "has local_update and no remote_updates.";
       return true;
     }
 
     // In this case, we simply merge the |local_update| and |remote_updates|.
-    VLOG(1) << "Has local_update and has remote_updates.";
+    SYNC_VLOG(1) << "has local_update and has remote_updates.";
 
+    SYNC_VLOG(1) << "loading " << prev_file;
     UserDictionaryStorage prev_storage(prev_file);
     prev_storage.Load();
 
+    SYNC_VLOG(1) << "loading " << cur_file;
     UserDictionaryStorage cur_storage(cur_file);
     cur_storage.Load();
 
     // Obtain local update.
+    SYNC_VLOG(1) << "making local update";
     UserDictionarySyncUtil::UserDictionaryStorageBase local_update;
     UserDictionarySyncUtil::CreateUpdate(prev_storage, cur_storage,
                                          &local_update);
 
     if (local_update.dictionaries_size() == 0) {
+      SYNC_VLOG(1) << "has no local_update in actual.";
       // no updates are found on the local.
       UserDictionarySyncUtil::MergeUpdates(remote_updates, &cur_storage);
-      if (!UserDictionarySyncUtil::LockAndSaveStorage(&cur_storage)) {
+      if (!UserDictionarySyncUtil::VerifyLockAndSaveStorage(&cur_storage)) {
+        SYNC_VLOG(1) << "cannot save cur_storage.";
         return false;
       }
-      VLOG(1) << "copying " << cur_file << " to " << prev_file;
+      SYNC_VLOG(1) << "copying " << cur_file << " to " << prev_file;
       if (!SyncUtil::CopyLastSyncedFile(cur_file, prev_file)) {
-        LOG(ERROR) << "cannot copy " << cur_file << " to " << prev_file;
+        SYNC_VLOG(1) << "cannot copy " << cur_file << " to " << prev_file;
         return false;
       }
     } else {
       // This case causes a conflict, so we make a backup just in case.
+      SYNC_VLOG(1) << "making a backup " << cur_storage.filename() << ".bak";
       if (!Util::CopyFile(cur_storage.filename(),
                           cur_storage.filename() + ".bak")) {
-        LOG(ERROR) << "cannot make backup file";
+        SYNC_VLOG(1) << "cannot make backup file";
       }
 
       // First, apply the |remote_updates| to the previous storage.
       // |prev_storage| only reflects the |remote_updates|.
+      SYNC_VLOG(1) << "merging remote_updates into prev_storage";
       UserDictionarySyncUtil::MergeUpdates(remote_updates, &prev_storage);
 
       // We apply the |remote_updates| and |local_update| to
       // the prev_storage. It can be seen as an approximation of
       // mixing |remote_updates| and |local_update|, it is not
       // perfect though.
+      SYNC_VLOG(1) << "coping prev_storage into cur_storage";
       cur_storage.CopyFrom(prev_storage);
+
+      SYNC_VLOG(1) << "merging local_update to cur_storage";
       UserDictionarySyncUtil::MergeUpdate(local_update, &cur_storage);
 
-      if (!UserDictionarySyncUtil::LockAndSaveStorage(&cur_storage)) {
+      SYNC_VLOG(1) << "saving cur_storage";
+      if (!UserDictionarySyncUtil::VerifyLockAndSaveStorage(&cur_storage)) {
+        SYNC_VLOG(1) << "cannot save cur_storage.";
         return false;
       }
+      // Even if a sync dictionary of |prev_storage| exceeds its limit after
+      // applying |remote_update| on prev_storage, we must save it. So we use
+      // LockAndSaveStorage() without verifications. Please refer
+      // http://b/5948831 for details.
+      SYNC_VLOG(1) << "saving prev_storage";
       if (!UserDictionarySyncUtil::LockAndSaveStorage(&prev_storage)) {
+        SYNC_VLOG(1) << "cannot save prev_storage.";
         return false;
       }
     }
@@ -183,10 +209,10 @@ bool UserDictionaryAdapter::SetDownloadedItems(
 
 bool UserDictionaryAdapter::GetItemsToUpload(ime_sync::SyncItems *items) {
   DCHECK(items);
-  VLOG(1) << "Start GetItemsToUpload()";
+  SYNC_VLOG(1) << "Start GetItemsToUpload()";
 
   if (!Util::FileExists(GetUserDictionaryFileName())) {
-    LOG(WARNING) << GetUserDictionaryFileName() << " does not exist.";
+    SYNC_VLOG(1) << GetUserDictionaryFileName() << " does not exist.";
     return true;
   }
 
@@ -195,7 +221,7 @@ bool UserDictionaryAdapter::GetItemsToUpload(ime_sync::SyncItems *items) {
 
   // No updates found on the local.
   if (Util::IsEqualFile(prev_file, cur_file)) {
-    VLOG(1) << "No changes found in local dictionary files.";
+    SYNC_VLOG(1) << "No changes found in local dictionary files.";
     return true;
   }
 
@@ -207,7 +233,7 @@ bool UserDictionaryAdapter::GetItemsToUpload(ime_sync::SyncItems *items) {
 
   // No updates found on the local.
   if (UserDictionarySyncUtil::IsEqualStorage(prev_storage, cur_storage)) {
-    VLOG(1) << "No need to upload updates.";
+    SYNC_VLOG(1) << "No need to upload updates.";
     return true;
   }
 
@@ -216,7 +242,7 @@ bool UserDictionaryAdapter::GetItemsToUpload(ime_sync::SyncItems *items) {
   // last synced file if upload is failed.
   const string tmp_file = GetTempLastSyncedUserDictionaryFileName();
   if (!SyncUtil::CopyLastSyncedFile(cur_file, tmp_file)) {
-    LOG(ERROR) << "cannot copy " << cur_file << " to " << tmp_file;
+    SYNC_VLOG(1) << "cannot copy " << cur_file << " to " << tmp_file;
     return false;
   }
 
@@ -244,7 +270,7 @@ bool UserDictionaryAdapter::GetItemsToUpload(ime_sync::SyncItems *items) {
 
   // No need to update the file.
   if (local_update->dictionaries_size() == 0) {
-    VLOG(1) << "No local update";
+    SYNC_VLOG(1) << "No local update";
     Util::Unlink(tmp_file);
     items->RemoveLast();
     return true;
@@ -256,7 +282,7 @@ bool UserDictionaryAdapter::GetItemsToUpload(ime_sync::SyncItems *items) {
   // create a snapshot instead.
   if (next_bucket_id == 0 ||
       UserDictionarySyncUtil::ShouldCreateSnapshot(*local_update)) {
-    VLOG(1) << "Start creating snapshot";
+    SYNC_VLOG(1) << "Start creating snapshot";
     // 0 is reserved for snapshot.
     next_bucket_id = 0;
     UserDictionarySyncUtil::CreateSnapshot(cur_storage, local_update);
@@ -269,27 +295,29 @@ bool UserDictionaryAdapter::GetItemsToUpload(ime_sync::SyncItems *items) {
 
 bool UserDictionaryAdapter::MarkUploaded(
     const ime_sync::SyncItem& item, bool uploaded) {
-  VLOG(1) << "Start MarkUploaded() uploaded=" << uploaded;
+  SYNC_VLOG(1) << "Start MarkUploaded() uploaded=" << uploaded;
 
   const string prev_file = GetLastSyncedUserDictionaryFileName();
   const string tmp_file = GetTempLastSyncedUserDictionaryFileName();
 
   if (!uploaded) {
     // Rollback the last synced file by removing the pending file.
+    SYNC_VLOG(1) << "rollbacking the last synced file: " << tmp_file;
     Util::Unlink(tmp_file);
     return true;
   }
 
   // Push the pending last synced file atomically.
-  VLOG(1) << "AtomicRename " << tmp_file << " to " << prev_file;
+  SYNC_VLOG(1) << "AtomicRename " << tmp_file << " to " << prev_file;
   if (!Util::AtomicRename(tmp_file, prev_file)) {
-    LOG(ERROR) << "cannot update: " << prev_file;
+    SYNC_VLOG(1) << "cannot update: " << prev_file;
     return false;
   }
 
   const uint32 next_bucket_id = GetNextBucketId();
+  SYNC_VLOG(1) << "updating next_bucket_id=" << next_bucket_id;
   if (!SetBucketId(next_bucket_id)) {
-    LOG(ERROR) << "cannot set bucket id";
+    SYNC_VLOG(1) << "cannot set bucket id";
     return false;
   }
 
@@ -297,6 +325,7 @@ bool UserDictionaryAdapter::MarkUploaded(
 }
 
 bool UserDictionaryAdapter::Clear() {
+  SYNC_VLOG(1) << "start Clear()";
   Util::Unlink(GetLastSyncedUserDictionaryFileName());
   Util::Unlink(GetTempLastSyncedUserDictionaryFileName());
   return true;
