@@ -38,6 +38,33 @@ TEST(ConfigUtilTest, IntValue) {
   mozc::config::Config config;
   EXPECT_EQ("", config.DebugString());
 
+#if IBUS_CHECK_VERSION(1, 3, 99)
+  GVariant *value = g_variant_new_int32(-56);
+#else
+  g_type_init();
+  GValue actual_value = {0};
+  GValue *value = &actual_value;
+  g_value_init(value, G_TYPE_INT);
+  g_value_set_int(value, -56);
+#endif
+  EXPECT_TRUE(mozc::ibus::ConfigUtil::SetFieldForName(
+      "verbose_level", value, &config));
+
+  EXPECT_EQ("verbose_level: -56\n",
+            config.DebugString());
+#if IBUS_CHECK_VERSION(1, 3, 99)
+  g_variant_unref(value);
+#else
+  g_value_unset(value);
+#endif
+}
+
+TEST(ConfigUtilTest, UnsignedIntValue) {
+  mozc::config::Config config;
+  EXPECT_EQ("", config.DebugString());
+
+  // unsigned int is not supported as chrome's preference type and
+  // int is used as an alternative type.
 #if IBUS_CHECK_VERSION(1, 3, 99)
   GVariant *value = g_variant_new_int32(42);
 #else
@@ -47,8 +74,8 @@ TEST(ConfigUtilTest, IntValue) {
   g_value_init(value, G_TYPE_INT);
   g_value_set_int(value, 42);
 #endif
-  mozc::ibus::ConfigUtil::SetFieldForName(
-      "suggestions_size", value, &config);
+  EXPECT_TRUE(mozc::ibus::ConfigUtil::SetFieldForName(
+      "suggestions_size", value, &config));
 
   EXPECT_EQ("suggestions_size: 42\n",
             config.DebugString());
@@ -72,8 +99,8 @@ TEST(ConfigUtilTest, EnumValue) {
   g_value_init(value, G_TYPE_STRING);
   g_value_set_static_string(value, "ROMAN");
 #endif
-  mozc::ibus::ConfigUtil::SetFieldForName(
-      "preedit_method", value, &config);
+  EXPECT_TRUE(mozc::ibus::ConfigUtil::SetFieldForName(
+      "preedit_method", value, &config));
 
   EXPECT_EQ("preedit_method: ROMAN\n",
             config.DebugString());
@@ -97,8 +124,8 @@ TEST(ConfigUtilTest, BooleanValue) {
   g_value_init(value, G_TYPE_BOOLEAN);
   g_value_set_boolean(value, true);
 #endif
-  mozc::ibus::ConfigUtil::SetFieldForName(
-      "incognito_mode", value, &config);
+  EXPECT_TRUE(mozc::ibus::ConfigUtil::SetFieldForName(
+      "incognito_mode", value, &config));
 
   EXPECT_EQ("incognito_mode: true\n",
             config.DebugString());
@@ -122,8 +149,8 @@ TEST(ConfigUtilTest, NoSuchField) {
   g_value_init(value, G_TYPE_INT);
   g_value_set_int(value, 10);
 #endif
-  mozc::ibus::ConfigUtil::SetFieldForName(
-      "no_such_field", value, &config);
+  EXPECT_FALSE(mozc::ibus::ConfigUtil::SetFieldForName(
+      "no_such_field", value, &config));
 
   // Does not affect the config value.
   EXPECT_EQ("", config.DebugString());
@@ -149,8 +176,8 @@ TEST(ConfigUtilTest, TypeMismatch) {
 #endif
 
   // enum field
-  mozc::ibus::ConfigUtil::SetFieldForName(
-      "preedit_method", value, &config);
+  EXPECT_FALSE(mozc::ibus::ConfigUtil::SetFieldForName(
+      "preedit_method", value, &config));
 
   // Does not affect the config value.
   EXPECT_EQ("", config.DebugString());
