@@ -54,6 +54,9 @@ const struct SpecialKeyMap {
   {IBUS_Hiragana, mozc::commands::KeyEvent::KANA},
   {IBUS_Hiragana_Katakana, mozc::commands::KeyEvent::KANA},
   {IBUS_Katakana, mozc::commands::KeyEvent::KATAKANA},
+  {IBUS_Zenkaku, mozc::commands::KeyEvent::HANKAKU},
+  {IBUS_Hankaku, mozc::commands::KeyEvent::HANKAKU},
+  {IBUS_Zenkaku_Hankaku, mozc::commands::KeyEvent::HANKAKU},
   {IBUS_Eisu_toggle, mozc::commands::KeyEvent::EISU},
   {IBUS_Home, mozc::commands::KeyEvent::HOME},
   {IBUS_End, mozc::commands::KeyEvent::END},
