@@ -38,9 +38,6 @@
 #include "session/commands.pb.h"
 #include "testing/base/public/gunit_prod.h"
 #include "unix/ibus/engine_interface.h"
-#ifdef ENABLE_GTK_RENDERER
-#include "renderer/renderer_client.h"
-#endif  // ENABLE_GTK_RENDERER
 
 #if !defined(OS_CHROMEOS) && IBUS_CHECK_VERSION(1, 2, 1)
 #define USE_IBUS_ENGINE_DELETE_SURROUNDING_TEXT
@@ -54,9 +51,12 @@ class ClientInterface;
 
 namespace ibus {
 
-class KeyTranslator;
+class CandidateWindowHandlerInterface;
+class KeyEventHandler;
 class LaunchToolTest;
 class MessageTranslatorInterface;
+class PreeditHandlerInterface;
+class PropertyHandlerInterface;
 
 // Implements EngineInterface and handles signals from IBus daemon.
 // This class mainly does the two things:
@@ -107,7 +107,6 @@ class MozcEngine : public EngineInterface {
   // The callback function to the "disconnected" signal to the bus object.
   static void Disconnected(IBusBus *bus, gpointer user_data);
   // The callback function to the "value-changed" signal to the config object.
-#ifdef OS_CHROMEOS
 #if IBUS_CHECK_VERSION(1, 3, 99)
   static void ConfigValueChanged(IBusConfig *config,
                                  const gchar *section,
@@ -123,50 +122,28 @@ class MozcEngine : public EngineInterface {
 #endif
 
   // Initializes mozc config.
-  // Currenly this cannot be used for Mozc Chewing.
   static void InitConfig(IBusConfig *config);
-#endif  // OS_CHROMEOS
 
-  // Manages modifier keys.  Returns false if it should not be sent to server.
-  // It is static for unittest.
-  static bool ProcessModifiers(
-      bool is_key_up,
-      gint keyval,
-      commands::KeyEvent *key,
-      bool *is_non_modifier_key_pressed,
-      set<gint> *currently_pressed_modifiers,
-      set<commands::KeyEvent::ModifierKey> *modifiers_to_be_sent);
+#if ENABLE_GTK_RENDERER
+  // Initialize RendererConfiguration.
+  // TODO(nona): Introduce ConfigHandler.
+  void InitRendererConfig(IBusConfig *config);
+#endif  // ENABLE_GTK_RENDERER
 
  private:
-  // Appends entries to the back of ibus root panel.
-  void AppendCompositionPropertyToPanel(
-      const MessageTranslatorInterface &translator);
-  void AppendToolPropertyToPanel(const MessageTranslatorInterface &translator);
-  void AppendSwitchPropertyToPanel(
-      const MessageTranslatorInterface &translator);
-
   // Updates the preedit text and the candidate window and inserts result
   // based on the content of |output|.
   bool UpdateAll(IBusEngine *engine, const commands::Output &output);
   // Inserts a result text based on the content of |output|.
   bool UpdateResult(IBusEngine *engine, const commands::Output &output) const;
-  // Updates the preedit text based on the content of |output|.
-  bool UpdatePreedit(IBusEngine *engine, const commands::Output &output) const;
-  // Updates the candidates based on the content of |output|.
-  bool UpdateCandidates(IBusEngine *engine,
-                        const commands::Output &output);
-  // Updates the auxiliary text based on the content of |output|.
-  // There are some situations that candidate window has auxiliary text without
-  // candidates. So we separate UpdateAuxiliaryText() from UpdateCandidates().
-  bool UpdateAuxiliaryText(IBusEngine *engine,
-                           const commands::Output &output) const;
+  // Updates |unique_candidate_ids_|.
+  bool UpdateCandidateIDMapping(const commands::Output &output);
   // Updates the deletion range message based on the content of |output|.
   bool UpdateDeletionRange(IBusEngine *engine, const commands::Output &output);
 
   // Updates the callback message based on the content of |output|.
   bool ExecuteCallback(IBusEngine *engine, const commands::Output &output);
   // Updates the configuration.
-#ifdef OS_CHROMEOS
 #if IBUS_CHECK_VERSION(1, 3, 99)
   void UpdateConfig(
       const gchar *section, const gchar *name, GVariant *gvalue);
@@ -174,22 +151,13 @@ class MozcEngine : public EngineInterface {
   void UpdateConfig(
       const gchar *section, const gchar *name, GValue *gvalue);
 #endif
-#endif  // OS_CHROMEOS
 
   // Launches Mozc tool with appropriate arguments.
   bool LaunchTool(const commands::Output &output) const;
 
-  // Updates the composition mode based on the content of |output|.
-  void UpdateCompositionModeIcon(
-      IBusEngine *engine, const commands::CompositionMode new_composition_mode);
   // Updates internal preedit_method (Roman/Kana) state
   void UpdatePreeditMethod();
 
-  // Sets the composition mode to |composition_mode|. Updates Mozc and IBus
-  // panel status.
-  void SetCompositionMode(IBusEngine *engine,
-                          commands::CompositionMode composition_mode);
-
   // Calls SyncData command. if |force| is false, SyncData is called
   // at an appropriate timing to reduce IPC calls. if |force| is true,
   // always calls SyncData.
@@ -199,17 +167,15 @@ class MozcEngine : public EngineInterface {
   // message, then hides a preedit string and the candidate window.
   void RevertSession(IBusEngine *engine);
 
-#ifdef ENABLE_GTK_RENDERER
-  // Hides native candidate window.
-  void HideNativeCandidateWindow();
-#endif  // ENABLE_GTK_RENDERER
+  // Sends current caret location to mozc_server.
+  void SendCaretLocation(uint32 x, uint32 y, uint32 width, uint32 height);
+
+  CandidateWindowHandlerInterface *GetCandidateWindowHandler(
+      IBusEngine *engine);
 
   uint64 last_sync_time_;
-  scoped_ptr<KeyTranslator> key_translator_;
+  scoped_ptr<KeyEventHandler> key_event_handler_;
   scoped_ptr<client::ClientInterface> client_;
-#ifdef ENABLE_GTK_RENDERER
-  scoped_ptr<renderer::RendererClient> renderer_;
-#endif  // ENABLE_GTK_RENDERER
 
 #ifndef USE_IBUS_ENGINE_DELETE_SURROUNDING_TEXT
   // A flag to avoid reverting session after deleting surrounding text.
@@ -217,24 +183,18 @@ class MozcEngine : public EngineInterface {
   bool ignore_reset_for_deletion_range_workaround_;
 #endif  // !USE_IBUS_ENGINE_DELETE_SURROUNDING_TEXT
 
-  IBusPropList *prop_root_;
-  IBusProperty *prop_composition_mode_;
-  IBusProperty *prop_mozc_tool_;
+  scoped_ptr<PropertyHandlerInterface> property_handler_;
+  scoped_ptr<PreeditHandlerInterface> preedit_handler_;
+
+  // TODO(nona): Introduce CandidateWindowHandlerManager to avoid direct access.
+  scoped_ptr<CandidateWindowHandlerInterface> gtk_candidate_window_handler_;
+  scoped_ptr<CandidateWindowHandlerInterface> ibus_candidate_window_handler_;
   vector<IBusProperty *> prop_switch_properties_;
-  commands::CompositionMode original_composition_mode_;
-  bool is_activated_;
   config::Config::PreeditMethod preedit_method_;
 
   // Unique IDs of candidates that are currently shown.
   vector<int32> unique_candidate_ids_;
 
-  // Non modifier key is pressed or not after all keys are released.
-  bool is_non_modifier_key_pressed_;
-  // Currently pressed modifier keys.  It is set of keyval.
-  set<gint> currently_pressed_modifiers_;
-  // Pending modifier keys.
-  set<commands::KeyEvent::ModifierKey> modifiers_to_be_sent_;
-
   friend class LaunchToolTest;
   FRIEND_TEST(LaunchToolTest, LaunchToolTest);
 
