@@ -61,12 +61,25 @@ class DummyMozcConnection : public mozc_unix_scim::MozcConnectionInterface {
   }
 
   virtual bool TrySendKeyEvent(const scim::KeyEvent &key,
+                               bool is_activated,
                                mozc::commands::CompositionMode composition_mode,
                                mozc::commands::Output *out,
                                string *out_error) const {
     return true;
   }
 
+  virtual bool TrySendImeOff(mozc::commands::CompositionMode next_mode,
+                             mozc::commands::Output *out,
+                             string *out_error) const {
+    return true;
+  }
+
+  virtual bool TrySendImeOn(mozc::commands::CompositionMode next_mode,
+                            mozc::commands::Output *out,
+                            string *out_error) const {
+    return true;
+  }
+
   virtual bool TrySendClick(int32 unique_id,
                             mozc::commands::Output *out,
                             string *out_error) const {
