@@ -48,8 +48,6 @@
 #include "base/version.h"
 #include "client/client_interface.h"
 #include "config/stats_config_util.h"
-#include "languages/global_language_spec.h"
-#include "languages/japanese/lang_dep_spec.h"
 #include "renderer/renderer_client.h"
 #include "server/cache_service_manager.h"
 #include "session/commands.pb.h"
@@ -80,7 +78,6 @@ const char kIEFrameDll[] = "ieframe.dll";
 const wchar_t kSystemSharedKey[] = L"Software\\Microsoft\\CTF\\SystemShared";
 
 HMODULE g_module = NULL;
-mozc::language::LanguageDependentSpecInterface *g_lang_spec_ptr = NULL;
 
 HRESULT CallSystemDllFunction(const char* dll_name,
                               const char* function_name) {
@@ -244,15 +241,9 @@ BOOL APIENTRY DllMain(HMODULE module,
   switch (ul_reason_for_call) {
     case DLL_PROCESS_ATTACH:
       g_module = module;
-      g_lang_spec_ptr = new mozc::japanese::LangDepSpecJapanese();
-      mozc::language::GlobalLanguageSpec::SetLanguageDependentSpec(
-          g_lang_spec_ptr);
       break;
     case DLL_PROCESS_DETACH:
       g_module = NULL;
-      mozc::language::GlobalLanguageSpec::SetLanguageDependentSpec(NULL);
-      delete g_lang_spec_ptr;
-      g_lang_spec_ptr = NULL;
       break;
     case DLL_THREAD_ATTACH:
     case DLL_THREAD_DETACH:
