@@ -38,8 +38,6 @@
 #include "client/client.h"
 #include "config/config_handler.h"
 #include "ipc/ipc_mock.h"
-#include "languages/global_language_spec.h"
-#include "languages/japanese/lang_dep_spec.h"
 #include "session/commands.pb.h"
 #include "session/ime_switch_util.h"
 #include "testing/base/public/googletest.h"
@@ -98,6 +96,8 @@ class TestServerLauncher : public client::ServerLauncherInterface {
 
   virtual void set_restricted(bool restricted) {}
 
+  virtual void set_suppress_error_dialog(bool suppress) {}
+
   virtual void set_server_program(const string &server_path) {}
 
   virtual const string &server_program() const {
@@ -164,27 +164,7 @@ class MockClient : public client::Client {
 };
 }  // anonymous namespace
 
-class ImeCoreTest : public testing::Test {
- protected:
-  ImeCoreTest() {}
-  virtual ~ImeCoreTest() {}
-  virtual void SetUp() {
-    mozc::language::GlobalLanguageSpec::SetLanguageDependentSpec(
-        &language_dependency_spec_japanese_);
-  }
-
-  virtual void TearDown() {
-    mozc::language::GlobalLanguageSpec::SetLanguageDependentSpec(NULL);
-  }
-
- private:
-  // We need to set a LangDepSpecJapanese to GlobalLanguageSpec on start up for
-  // testing, and the actual instance does not have to be LangDepSpecJapanese.
-  mozc::japanese::LangDepSpecJapanese language_dependency_spec_japanese_;
-  DISALLOW_COPY_AND_ASSIGN(ImeCoreTest);
-};
-
-TEST_F(ImeCoreTest, OpenIME) {
+TEST(ImeCoreTest, OpenIME) {
   commands::Output mock_output;
   mock_output.set_consumed(true);
   mock_output.set_elapsed_time(10);
@@ -212,7 +192,7 @@ TEST_F(ImeCoreTest, OpenIME) {
   }
 }
 
-TEST_F(ImeCoreTest, CloseIME) {
+TEST(ImeCoreTest, CloseIME) {
   commands::Output mock_output;
   mock_output.set_consumed(true);
   mock_output.set_elapsed_time(10);
@@ -239,7 +219,7 @@ TEST_F(ImeCoreTest, CloseIME) {
   }
 }
 
-TEST_F(ImeCoreTest, GetSupportableConversionMode) {
+TEST(ImeCoreTest, GetSupportableConversionMode) {
   EXPECT_EQ(IME_CMODE_NATIVE | IME_CMODE_FULLSHAPE,
             ImeCore::GetSupportableConversionMode(
                 IME_CMODE_NATIVE | IME_CMODE_FULLSHAPE));
@@ -249,7 +229,7 @@ TEST_F(ImeCoreTest, GetSupportableConversionMode) {
                 IME_CMODE_NATIVE | IME_CMODE_FULLSHAPE | IME_CMODE_ROMAN));
 }
 
-TEST_F(ImeCoreTest, GetSupportableConversionMode_Issue2914115) {
+TEST(ImeCoreTest, GetSupportableConversionMode_Issue2914115) {
   // http://b/2914115
   // In some environment, its initial conversion mode is IME_CMODE_NATIVE
   // (only), which is not the one of the expected conversion modes for Mozc.
@@ -258,7 +238,7 @@ TEST_F(ImeCoreTest, GetSupportableConversionMode_Issue2914115) {
             ImeCore::GetSupportableConversionMode(IME_CMODE_NATIVE));
 }
 
-TEST_F(ImeCoreTest, GetSupportableSentenceMode) {
+TEST(ImeCoreTest, GetSupportableSentenceMode) {
   // Always returns IME_SMODE_PHRASEPREDICT.
   EXPECT_EQ(IME_SMODE_PHRASEPREDICT,
             ImeCore::GetSupportableSentenceMode(IME_SMODE_NONE));
@@ -285,7 +265,7 @@ TEST_F(ImeCoreTest, GetSupportableSentenceMode) {
             ImeCore::GetSupportableSentenceMode(MAXDWORD));
 }
 
-TEST_F(ImeCoreTest, GetSupportableSentenceMode_Issue2955175) {
+TEST(ImeCoreTest, GetSupportableSentenceMode_Issue2955175) {
   // b/2955175
   // If Mozc leaves the sentence mode IME_SMODE_NONE and switch to MS-IME in
   // Sylpheed, MS-IME cannot convert composition string because it's in
@@ -398,7 +378,7 @@ const UIMessage kMsgCloseCandidate(WM_IME_NOTIFY,
 
 // Check UI message order for
 //   "Hankaku/Zenkaku" -> "(Shift +)G" -> "Hankaku/Zenkaku"
-TEST_F(ImeCoreTest, TemporalConversionModeMessageOrderTest) {
+TEST(ImeCoreTest, TemporalConversionModeMessageOrderTest) {
   // "Hankaku/Zenkaku"
   {
     vector<UIMessage> composition_messages;
@@ -470,7 +450,7 @@ TEST_F(ImeCoreTest, TemporalConversionModeMessageOrderTest) {
 
 // Check UI message order for
 //   "Hankaku/Zenkaku" -> "(Shift +)G" -> "o" -> "Enter" -> "Hankaku/Zenkaku"
-TEST_F(ImeCoreTest, CompositionMessageOrderTest) {
+TEST(ImeCoreTest, CompositionMessageOrderTest) {
   // "Hankaku/Zenkaku"
   {
     vector<UIMessage> composition_messages;
@@ -584,7 +564,7 @@ TEST_F(ImeCoreTest, CompositionMessageOrderTest) {
 
 // Check UI message order for
 //   "Hankaku/Zenkaku" -> "a" -> "Space" -> "Space" -> "Space" -> "A"
-TEST_F(ImeCoreTest, CandidateMessageOrderTest) {
+TEST(ImeCoreTest, CandidateMessageOrderTest) {
   // "Hankaku/Zenkaku"
   {
     vector<UIMessage> composition_messages;
